package betterquesting.commands.admin;

import betterquesting.api.properties.NativeProps;
import betterquesting.api.storage.BQ_Settings;
import betterquesting.api.utils.JsonHelper;
import betterquesting.api.utils.NBTConverter;
import betterquesting.commands.QuestCommandBase;
import betterquesting.handlers.SaveLoadHandler;
import betterquesting.legacy.ILegacyLoader;
import betterquesting.legacy.LegacyLoaderRegistry;
import betterquesting.network.handlers.NetChapterSync;
import betterquesting.network.handlers.NetQuestSync;
import betterquesting.network.handlers.NetSettingSync;
import betterquesting.questing.QuestDatabase;
import betterquesting.questing.QuestLineDatabase;
import betterquesting.storage.QuestSettings;
import com.google.gson.JsonObject;
import java.io.File;
import java.util.ArrayList;
import java.util.List;
import net.minecraft.command.CommandBase;
import net.minecraft.command.ICommandSender;
import net.minecraft.entity.player.EntityPlayerMP;
import net.minecraft.nbt.NBTTagCompound;
import net.minecraft.nbt.NBTTagList;
import net.minecraft.server.MinecraftServer;
import net.minecraft.util.ChatComponentTranslation;

/* loaded from: betterquesting_commands_admin.jar:betterquesting/commands/admin/QuestCommandDefaults.class */
public class QuestCommandDefaults extends QuestCommandBase {
    public String getUsageSuffix() {
        return "[save|load|set] [file_name]";
    }

    public boolean validArgs(String[] args) {
        return args.length == 2 || args.length == 3;
    }

    public List<String> autoComplete(MinecraftServer server, ICommandSender sender, String[] args) {
        List<String> list = new ArrayList<>();
        if (args.length == 2) {
            return CommandBase.func_71530_a(args, new String[]{"save", "load", "set"});
        }
        if (args.length == 3) {
            list.add("DefaultQuests");
        }
        return list;
    }

    public String getCommand() {
        return "default";
    }

    public void runCommand(MinecraftServer server, CommandBase command, ICommandSender sender, String[] args) {
        File qFile;
        if (args.length == 3 && !args[2].equalsIgnoreCase("DefaultQuests")) {
            qFile = new File(BQ_Settings.defaultDir, "saved_quests/" + args[2] + ".json");
        } else {
            qFile = new File(BQ_Settings.defaultDir, "DefaultQuests.json");
        }
        if (args[1].equalsIgnoreCase("save")) {
            NBTTagCompound base = new NBTTagCompound();
            base.func_74782_a("questSettings", QuestSettings.INSTANCE.writeToNBT(new NBTTagCompound()));
            base.func_74782_a("questDatabase", QuestDatabase.INSTANCE.writeToNBT(new NBTTagList(), (List) null));
            base.func_74782_a("questLines", QuestLineDatabase.INSTANCE.writeToNBT(new NBTTagList(), (List) null));
            base.func_74778_a("format", "2.0.0");
            JsonHelper.WriteToFile(qFile, NBTConverter.NBTtoJSON_Compound(base, new JsonObject(), true));
            if (args.length == 3 && !args[2].equalsIgnoreCase("DefaultQuests")) {
                sender.func_145747_a(new ChatComponentTranslation("betterquesting.cmd.default.save2", new Object[]{args[2] + ".json"}));
                return;
            } else {
                sender.func_145747_a(new ChatComponentTranslation("betterquesting.cmd.default.save", new Object[0]));
                return;
            }
        }
        if (args[1].equalsIgnoreCase("load")) {
            if (qFile.exists()) {
                boolean editMode = ((Boolean) QuestSettings.INSTANCE.getProperty(NativeProps.EDIT_MODE)).booleanValue();
                boolean hardMode = ((Boolean) QuestSettings.INSTANCE.getProperty(NativeProps.HARDCORE)).booleanValue();
                NBTTagList jsonP = QuestDatabase.INSTANCE.writeProgressToNBT(new NBTTagList(), (List) null);
                JsonObject j1 = JsonHelper.ReadFromFile(qFile);
                NBTTagCompound nbt1 = NBTConverter.JSONtoNBT_Object(j1, new NBTTagCompound(), true);
                ILegacyLoader loader = LegacyLoaderRegistry.getLoader(nbt1.func_150297_b("format", 8) ? nbt1.func_74779_i("format") : "0.0.0");
                if (loader == null) {
                    QuestSettings.INSTANCE.readFromNBT(nbt1.func_74775_l("questSettings"));
                    QuestDatabase.INSTANCE.readFromNBT(nbt1.func_150295_c("questDatabase", 10), false);
                    QuestLineDatabase.INSTANCE.readFromNBT(nbt1.func_150295_c("questLines", 10), false);
                } else {
                    loader.readFromJson(j1);
                }
                QuestDatabase.INSTANCE.readProgressFromNBT(jsonP, false);
                QuestSettings.INSTANCE.setProperty(NativeProps.EDIT_MODE, Boolean.valueOf(editMode));
                QuestSettings.INSTANCE.setProperty(NativeProps.HARDCORE, Boolean.valueOf(hardMode));
                if (args.length == 3 && !args[2].equalsIgnoreCase("DefaultQuests")) {
                    sender.func_145747_a(new ChatComponentTranslation("betterquesting.cmd.default.load2", new Object[]{args[2] + ".json"}));
                } else {
                    sender.func_145747_a(new ChatComponentTranslation("betterquesting.cmd.default.load", new Object[0]));
                }
                NetSettingSync.sendSync((EntityPlayerMP) null);
                NetQuestSync.quickSync(-1, true, true);
                NetChapterSync.sendSync((EntityPlayerMP) null, (int[]) null);
                SaveLoadHandler.INSTANCE.markDirty();
                return;
            }
            sender.func_145747_a(new ChatComponentTranslation("betterquesting.cmd.default.none", new Object[0]));
            return;
        }
        if (args[1].equalsIgnoreCase("set") && args.length == 3) {
            if (qFile.exists() && !args[2].equalsIgnoreCase("DefaultQuests")) {
                File defFile = new File(BQ_Settings.defaultDir, "DefaultQuests.json");
                if (defFile.exists()) {
                    defFile.delete();
                }
                JsonHelper.CopyPaste(qFile, defFile);
                sender.func_145747_a(new ChatComponentTranslation("betterquesting.cmd.default.set", new Object[]{args[2]}));
                return;
            }
            sender.func_145747_a(new ChatComponentTranslation("betterquesting.cmd.default.none", new Object[0]));
            return;
        }
        throw getException(command);
    }
}
